# exclude plugin .so from provides
%global __provides_exclude_from ^%{_libdir}/%{name}/(plugins|views)/.*\\.so$

Name:           darktable
Version:        1.6.8
Release:        %mkrel 1
Summary:        Open source photography workflow application and RAW developer
Group:          Graphics/Photography
License:        GPLv3+
Url:            http://www.darktable.org
Source0:        https://github.com/darktable-org/darktable/releases/download/release-%{version}/%{name}-%{version}.tar.xz
Source1:        FindOsmGpsMap.cmake
Patch0:         darktable-1.6.0-use-system-osmgpsmap.patch

BuildRequires:  cmake
BuildRequires:  gnome-doc-utils
BuildRequires:  intltool
BuildRequires:  jpeg-devel
BuildRequires:  libgomp-devel
BuildRequires:  pkgconfig(colord)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(exiv2)
BuildRequires:  pkgconfig(flickcurl)
BuildRequires:  pkgconfig(gnome-keyring-1)
BuildRequires:  pkgconfig(GraphicsMagick)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(lensfun)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libgphoto2)
BuildRequires:  pkgconfig(libopenjpeg1)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(lua) >= 5.2
BuildRequires:  pkgconfig(OpenEXR)
BuildRequires:  pkgconfig(osmgpsmap)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  xsltproc

%description
Darktable is an open source photography workflow application and
RAW developer. A virtual lighttable and darkroom for photographers.
It manages your digital negatives in a database, lets you view them
through a zoomable lighttable and enables you to develop raw images
and enhance them.

%prep
%setup -q
%apply_patches

#build with system osm-gps-map
install -Dpm644 %{_sourcedir}/FindOsmGpsMap.cmake cmake/modules/FindOsmGpsMap.cmake
rm -rf src/external/osm-gps-map/

%build
%cmake -DBINARY_PACKAGE_BUILD=ON
%make

%install
%makeinstall_std -C build

#handle docs in files section
rm -rf %{buildroot}%{_docdir}

#to find libdarktable.so
mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d
cat > %{buildroot}%{_sysconfdir}/ld.so.conf.d/%{name}-%{_arch}.conf << EOF
%{_libdir}/%{name}
EOF

%find_lang %name

%files -f %{name}.lang
%doc doc/AUTHORS doc/NEWS doc/TODO doc/TRANSLATORS
%config %{_sysconfdir}/ld.so.conf.d/%{name}-%{_arch}.conf
%{_bindir}/%{name}
%{_bindir}/%{name}-cltest
%{_bindir}/%{name}-cli
%{_bindir}/%{name}-cmstest
%{_bindir}/%{name}-viewer
%{_datadir}/applications/%{name}.desktop
%{_datadir}/%{name}/
%{_datadir}/appdata/%{name}.appdata.xml
%{_iconsdir}/hicolor/*/apps/%{name}*
%{_libdir}/%{name}/
%{_mandir}/man1/%{name}.1.*
%{_mandir}/man1/%{name}-cli.1.*


%changelog
* Sun Aug 23 2015 akien <akien> 1.6.8-1.mga5
+ Revision: 868220
- Version 1.6.8, fixes mga#16633
- Bugfix version 1.6.7
- Remove upstreamed patch for CVE-2015-3885

* Tue May 12 2015 akien <akien> 1.6.6-1.mga5
+ Revision: 821938
- Version 1.6.6
- Simplify package description
- Add patch for security vulnerability in libraw (mga#15915)

* Sun Mar 08 2015 akien <akien> 1.6.3-1.mga5
+ Revision: 818184
- Version 1.6.3

* Sun Feb 22 2015 anaselli <anaselli> 1.6.2-2.mga5
+ Revision: 816400
- rebuilt for new libgphoto2

* Tue Feb 03 2015 akien <akien> 1.6.2-1.mga5
+ Revision: 813241
- Version 1.6.2

* Fri Jan 09 2015 akien <akien> 1.6.1-1.mga5
+ Revision: 809629
- Version 1.6.1
- Build against OpenMP for additional threading support

* Sun Dec 14 2014 akien <akien> 1.6.0-1.mga5
+ Revision: 802967
- Version 1.6.0

* Wed Oct 15 2014 umeabot <umeabot> 1.4.2-7.mga5
+ Revision: 748549
- Second Mageia 5 Mass Rebuild

* Thu Sep 18 2014 umeabot <umeabot> 1.4.2-6.mga5
+ Revision: 693726
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 1.4.2-5.mga5
+ Revision: 678671
- Mageia 5 Mass Rebuild

* Sun Aug 24 2014 luigiwalser <luigiwalser> 1.4.2-4.mga5
+ Revision: 666987
- rebuild for ilmbase and OpenEXR

* Tue Jun 24 2014 barjac <barjac> 1.4.2-3.mga5
+ Revision: 639287
- add -DBINARY_PACKAGE_BUILD=On to maybe fix mga#12510
- replace %%make
- fix tabs/spaces
- Correct summary
- Correct capitalization and punctuation in description
- Change form of one BR to satisfy rpmlint

* Mon Jun 23 2014 doktor5000 <doktor5000> 1.4.2-2.mga5
+ Revision: 639040
- do not use parallel make, try to fix (mga#12510)

* Sun May 04 2014 akien <akien> 1.4.2-1.mga5
+ Revision: 619975
- Version 1.4.2

* Thu May 01 2014 luigiwalser <luigiwalser> 1.4.1-2.mga5
+ Revision: 619149
- rebuild for ilmbase

* Sat Feb 15 2014 dams <dams> 1.4.1-1.mga5
+ Revision: 592407
- new version 1.4.1

* Mon Feb 10 2014 dams <dams> 1.4-2.mga5
+ Revision: 588969
- rebuild for new exiv2

* Tue Feb 04 2014 dams <dams> 1.4-1.mga5
+ Revision: 581091
- clean specfile

* Thu Jan 30 2014 petos <petos> 1.4-1.mga4
+ Revision: 568561
- New version -  1.4

* Sat Oct 19 2013 umeabot <umeabot> 1.2.3-4.mga4
+ Revision: 534824
- Mageia 4 Mass Rebuild

* Sat Sep 14 2013 wally <wally> 1.2.3-3.mga4
+ Revision: 478963
- rebuild for new colord

* Sat Sep 14 2013 wally <wally> 1.2.3-2.mga4
+ Revision: 478784
- add ld.so.conf file to help locating needed private lib (mga#11228)
- exclude plugin .so from provides
- build with system osm-gps-map
- rediff glibdir patch to apply with %%apply_patches
- handle docs in files section

* Fri Sep 13 2013 dams <dams> 1.2.3-1.mga4
+ Revision: 478568
- new version 1.2.3

  + fwang <fwang>
    - br GraphicsMagick

* Thu Sep 12 2013 fwang <fwang> 1.2.2-3.mga4
+ Revision: 477878
- use cmake macro

* Thu Sep 12 2013 fwang <fwang> 1.2.2-2.mga4
+ Revision: 477862
- rebuild for new openexr

* Fri Jun 28 2013 dams <dams> 1.2.2-1.mga4
+ Revision: 447882
- new version 1.2.2

* Mon Jun 03 2013 fwang <fwang> 1.2.1-2.mga4
+ Revision: 435818
- fix br
- rebuild for new libpng

* Tue May 28 2013 dams <dams> 1.2.1-1.mga4
+ Revision: 429035
- new version 1.2.1

* Mon Apr 08 2013 dams <dams> 1.2-1.mga3
+ Revision: 409074
- new version 1.2

* Wed Mar 27 2013 dams <dams> 1.1.4-1.mga3
+ Revision: 405752
- new version 1.1.4

* Fri Mar 08 2013 dams <dams> 1.1.3-1.mga3
+ Revision: 401787
- new version 1.1.3
- Fix BuildRequires to build 'darktable-viewer' (add 'SDL-devel')
- Add 'colord-devel' as a BuildRequires to remove warning during build

* Fri Jan 11 2013 umeabot <umeabot> 1.1.1-2.mga3
+ Revision: 348612
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 13 2012 petos <petos> 1.1.1-1.mga3
+ Revision: 330355
- New version of Darktable. Lot of bugfixes...

* Sun Dec 02 2012 petos <petos> 1.1-1.mga3
+ Revision: 325634
- br OpenEXR
- Update to new version 1.1

* Sun Dec 02 2012 fwang <fwang> 1.0.5-6.mga3
+ Revision: 324978
- br openexr
- rebuild for new ilmbase

  + dams <dams>
    - update %%Group with new policy

* Mon Aug 27 2012 petos <petos> 1.0.5-4.mga3
+ Revision: 284557
- update br
- update rel
- update
- Updated message
- Typo fixed
- Reverted fwang's changes -- breaking package in 64bit system

* Sun Aug 05 2012 fwang <fwang> 1.0.5-3.mga3
+ Revision: 278929
- use system cmake macro

* Sun Aug 05 2012 fwang <fwang> 1.0.5-2.mga3
+ Revision: 278924
- rebuild for new gphoto

* Tue Jul 24 2012 petos <petos> 1.0.5-1.mga3
+ Revision: 274111
- Updated to new version

* Sun Jun 24 2012 petos <petos> 1.0.4-4.mga3
+ Revision: 263307
- fixed build
- Removed malfunctioned patch

* Tue Jun 19 2012 petos <petos> 1.0.4-3.mga3
+ Revision: 262012
- New buildrequires flickcurl-devel
- New buildRequire

* Mon Jun 18 2012 fwang <fwang> 1.0.4-2.mga3
+ Revision: 261637
- find correct path in lib64
- add more br
- br exiv
- cleanup spec

* Thu Jun 07 2012 petos <petos> 1.0.4-1.mga3
+ Revision: 257147
- Updated to new version

* Fri May 11 2012 dams <dams> 1.0.3-1.mga2
+ Revision: 235255
- new version 1.0.3

* Sun Apr 15 2012 petos <petos> 1.0-1.mga2
+ Revision: 230874
- imported package darktable

